@@ -36,6 +36,8 @@ static void addCredits (KAboutData & about);
 
 int main (int argc, char **argv)
 {
+    // Fixes blurry icons with fractional scaling
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("kgoldrunner");
